==> libopenshot-0.3.2-x86_64-2ponce.txz: usr/doc/libopenshot-0.3.2/API/search/all_18.js <==
var searchData=
[
  ['va_20api_20video_20acceleration_20api_0',['Libva / VA-API (Video Acceleration API)',['../md__2tmp_2sbopkg_8NNCQoQ_2libopenshot-0_83_82_2doc_2HW-ACCEL.html#autotoc_md10',1,'']]],
  ['variables_1',['Variables',['../md__2tmp_2sbopkg_8NNCQoQ_2libopenshot-0_83_82_2doc_2INSTALL-WINDOWS.html#autotoc_md87',1,'Environment Variables'],['../md__2tmp_2sbopkg_8NNCQoQ_2libopenshot-0_83_82_2doc_2INSTALL-WINDOWS.html#autotoc_md88',1,'Example Variables']]],
  ['vcodec_2',['vcodec',['../structopenshot_1_1ReaderInfo.html#a86ada063b274302db6cfbf529c840280',1,'openshot::ReaderInfo::vcodec'],['../structopenshot_1_1WriterInfo.html#a4026b18c379990e815c5948a54da6457',1,'openshot::WriterInfo::vcodec']]],
  ['vectors_3',['vectors',['../structopenshot_1_1AudioWaveformData.html#ab21882b8962523ed6abf92354e314aec',1,'openshot::AudioWaveformData']]],
  ['versions_4',['Supported FFmpeg Versions',['../md__2tmp_2sbopkg_8NNCQoQ_2libopenshot-0_83_82_2doc_2HW-ACCEL.html#autotoc_md8',1,'']]],
  ['vertical_5fradius_5',['vertical_radius',['../classopenshot_1_1Blur.html#a0edb4fe4aac343ec9c5dac942d39899e',1,'openshot::Blur']]],
  ['video_20acceleration_20api_6',['Libva / VA-API (Video Acceleration API)',['../md__2tmp_2sbopkg_8NNCQoQ_2libopenshot-0_83_82_2doc_2HW-ACCEL.html#autotoc_md10',1,'']]],
  ['video_20editing_20library_20c_20api_7',['OpenShot Video Editing Library C++ API',['../index.html',1,'']]],
  ['video_5fbit_5frate_8',['video_bit_rate',['../structopenshot_1_1ReaderInfo.html#a2723de5bccc7c0c8ebe30956267fe253',1,'openshot::ReaderInfo::video_bit_rate'],['../structopenshot_1_1WriterInfo.html#a13655c111c621d2895e354005b87a735',1,'openshot::WriterInfo::video_bit_rate']]],
  ['video_5fcache_5fmax_5fframes_9',['VIDEO_CACHE_MAX_FRAMES',['../classopenshot_1_1Settings.html#a95eb78b9202f69234dada483f38d6c03',1,'openshot::Settings']]],
  ['video_5fcache_5fmax_5fpreroll_5fframes_10',['VIDEO_CACHE_MAX_PREROLL_FRAMES',['../classopenshot_1_1Settings.html#af4a176e6d9cb64e5354ec4d19debd6ac',1,'openshot::Settings']]],
  ['video_5fcache_5fmin_5fpreroll_5fframes_11',['VIDEO_CACHE_MIN_PREROLL_FRAMES',['../classopenshot_1_1Settings.html#a875252749c32f03b5da0d86f8e76862c',1,'openshot::Settings']]],
  ['video_5fcache_5fpercent_5fahead_12',['VIDEO_CACHE_PERCENT_AHEAD',['../classopenshot_1_1Settings.html#acc6b24725d1c48837e45af1226c20c9c',1,'openshot::Settings']]],
  ['video_5fdecoded_13',['video_decoded',['../structopenshot_1_1PacketStatus.html#a827ec956bb15f1e61501e73ab36b64ef',1,'openshot::PacketStatus']]],
  ['video_5feof_14',['video_eof',['../structopenshot_1_1PacketStatus.html#aea56e6e74fab4544b761e781c2eff86c',1,'openshot::PacketStatus']]],
  ['video_5flength_15',['video_length',['../structopenshot_1_1ReaderInfo.html#a58fb59953df673c0240b6398b36f198f',1,'openshot::ReaderInfo::video_length'],['../structopenshot_1_1WriterInfo.html#a1ae6851f699eb16ce0f39fa9c72e9ba8',1,'openshot::WriterInfo::video_length']]],
  ['video_5fread_16',['video_read',['../structopenshot_1_1PacketStatus.html#a2d1c773f2d2ae14e45f11a7f1248d9da',1,'openshot::PacketStatus']]],
  ['video_5fstream_17',['VIDEO_STREAM',['../namespaceopenshot.html#ae2d6caab1dfb8202280cd5343a6505e3ae32ee67edd46165c463d8d2157004ca8',1,'openshot']]],
  ['video_5fstream_5findex_18',['video_stream_index',['../structopenshot_1_1ReaderInfo.html#ab3c62d7a199bf5de82f072c198a0dcdd',1,'openshot::ReaderInfo::video_stream_index'],['../structopenshot_1_1WriterInfo.html#abe6d885c6de152d1e223628eb647a2d4',1,'openshot::WriterInfo::video_stream_index']]],
  ['video_5ftimebase_19',['video_timebase',['../structopenshot_1_1ReaderInfo.html#ab1c961070c49398c485d5f016d7f25de',1,'openshot::ReaderInfo::video_timebase'],['../structopenshot_1_1WriterInfo.html#a91aa7f67fb7569726611be44aa5d011d',1,'openshot::WriterInfo::video_timebase']]],
  ['videocachethread_20',['VideoCacheThread',['../classopenshot_1_1VideoCacheThread.html',1,'openshot::VideoCacheThread'],['../classopenshot_1_1VideoCacheThread.html#a724e9c63303a008009d4f5dda68bfa8f',1,'openshot::VideoCacheThread::VideoCacheThread()']]],
  ['videocachethread_2ecpp_21',['VideoCacheThread.cpp',['../VideoCacheThread_8cpp.html',1,'']]],
  ['videocachethread_2eh_22',['VideoCacheThread.h',['../VideoCacheThread_8h.html',1,'']]],
  ['videoplaybackthread_23',['VideoPlaybackThread',['../classopenshot_1_1VideoPlaybackThread.html',1,'openshot']]],
  ['videoplaybackthread_2ecpp_24',['VideoPlaybackThread.cpp',['../VideoPlaybackThread_8cpp.html',1,'']]],
  ['videoplaybackthread_2eh_25',['VideoPlaybackThread.h',['../VideoPlaybackThread_8h.html',1,'']]],
  ['videorenderer_26',['VideoRenderer',['../classVideoRenderer.html',1,'VideoRenderer'],['../classVideoRenderer.html#a8af553b52aa088507190150093dd2676',1,'VideoRenderer::VideoRenderer()']]],
  ['videorenderer_2ecpp_27',['VideoRenderer.cpp',['../VideoRenderer_8cpp.html',1,'']]],
  ['videorenderer_2eh_28',['VideoRenderer.h',['../VideoRenderer_8h.html',1,'']]],
  ['videorenderwidget_29',['VideoRenderWidget',['../classVideoRenderWidget.html',1,'VideoRenderWidget'],['../classVideoRenderWidget.html#aff205f3e99ad0eeaf76a24134f90ca1e',1,'VideoRenderWidget::VideoRenderWidget()']]],
  ['videorenderwidget_2ecpp_30',['VideoRenderWidget.cpp',['../VideoRenderWidget_8cpp.html',1,'']]],
  ['videorenderwidget_2eh_31',['VideoRenderWidget.h',['../VideoRenderWidget_8h.html',1,'']]],
  ['viewport_5fscale_32',['viewport_scale',['../classopenshot_1_1Timeline.html#a1225a0f042308fbaf609de1d27a394c0',1,'openshot::Timeline']]],
  ['viewport_5fx_33',['viewport_x',['../classopenshot_1_1Timeline.html#ae9ad76791f3b3075aca19e668430e888',1,'openshot::Timeline']]],
  ['viewport_5fy_34',['viewport_y',['../classopenshot_1_1Timeline.html#af9ea1523546d9312afb9514b24bfda43',1,'openshot::Timeline']]],
  ['visible_35',['visible',['../classopenshot_1_1TrackedObjectBase.html#a632a1fa24937f794247af676c648200a',1,'openshot::TrackedObjectBase']]],
  ['volume_36',['volume',['../classopenshot_1_1Clip.html#a9253001dabbb8fffd17f8ef3eec78596',1,'openshot::Clip::volume'],['../classopenshot_1_1PlayerBase.html#a3e0a8ee8470773b73e7f455244dce53a',1,'openshot::PlayerBase::volume']]],
  ['volume_37',['Volume',['../classopenshot_1_1PlayerBase.html#a5822abc4b487f5ce93952373d385eb84',1,'openshot::PlayerBase::Volume()=0'],['../classopenshot_1_1PlayerBase.html#a78be80618d729d1690bd236018f702f1',1,'openshot::PlayerBase::Volume(float new_volume)=0'],['../classopenshot_1_1QtPlayer.html#ab7dce1b851993fa750cb4da820c6381f',1,'openshot::QtPlayer::Volume()'],['../classopenshot_1_1QtPlayer.html#ae8bd803779a6eb011c200b11ca684b1f',1,'openshot::QtPlayer::Volume(float new_volume)']]],
  ['volume_5fmix_5faverage_38',['VOLUME_MIX_AVERAGE',['../namespaceopenshot.html#aab56179b76f10ed8680d6df8b77a080ba0234f08bf2a1ab7e0cd1d4f9b918c6c9',1,'openshot']]],
  ['volume_5fmix_5fnone_39',['VOLUME_MIX_NONE',['../namespaceopenshot.html#aab56179b76f10ed8680d6df8b77a080ba494683e0605eb9c22155d754921b47c0',1,'openshot']]],
  ['volume_5fmix_5freduce_40',['VOLUME_MIX_REDUCE',['../namespaceopenshot.html#aab56179b76f10ed8680d6df8b77a080ba6ad226272ac83f5c935973a620e0cf29',1,'openshot']]],
  ['volumemixtype_41',['VolumeMixType',['../namespaceopenshot.html#aab56179b76f10ed8680d6df8b77a080b',1,'openshot']]]
];

==> libopenshot-0.3.3-x86_64-1ponce.txz: usr/doc/libopenshot-0.3.3/API/search/all_18.js <==
var searchData=
[
  ['va_20api_20video_20acceleration_20api_0',['Libva / VA-API (Video Acceleration API)',['../md__2tmp_2sbopkg_8sPtMvf_2libopenshot-0_83_83_2doc_2HW-ACCEL.html#autotoc_md10',1,'']]],
  ['variables_1',['Variables',['../md__2tmp_2sbopkg_8sPtMvf_2libopenshot-0_83_83_2doc_2INSTALL-WINDOWS.html#autotoc_md87',1,'Environment Variables'],['../md__2tmp_2sbopkg_8sPtMvf_2libopenshot-0_83_83_2doc_2INSTALL-WINDOWS.html#autotoc_md88',1,'Example Variables']]],
  ['vcodec_2',['vcodec',['../structopenshot_1_1ReaderInfo.html#a86ada063b274302db6cfbf529c840280',1,'openshot::ReaderInfo::vcodec'],['../structopenshot_1_1WriterInfo.html#a4026b18c379990e815c5948a54da6457',1,'openshot::WriterInfo::vcodec']]],
  ['vectors_3',['vectors',['../structopenshot_1_1AudioWaveformData.html#ab21882b8962523ed6abf92354e314aec',1,'openshot::AudioWaveformData']]],
  ['versions_4',['Supported FFmpeg Versions',['../md__2tmp_2sbopkg_8sPtMvf_2libopenshot-0_83_83_2doc_2HW-ACCEL.html#autotoc_md8',1,'']]],
  ['vertical_5fradius_5',['vertical_radius',['../classopenshot_1_1Blur.html#a0edb4fe4aac343ec9c5dac942d39899e',1,'openshot::Blur']]],
  ['video_20acceleration_20api_6',['Libva / VA-API (Video Acceleration API)',['../md__2tmp_2sbopkg_8sPtMvf_2libopenshot-0_83_83_2doc_2HW-ACCEL.html#autotoc_md10',1,'']]],
  ['video_20editing_20library_20c_20api_7',['OpenShot Video Editing Library C++ API',['../index.html',1,'']]],
  ['video_5fbit_5frate_8',['video_bit_rate',['../structopenshot_1_1ReaderInfo.html#a2723de5bccc7c0c8ebe30956267fe253',1,'openshot::ReaderInfo::video_bit_rate'],['../structopenshot_1_1WriterInfo.html#a13655c111c621d2895e354005b87a735',1,'openshot::WriterInfo::video_bit_rate']]],
  ['video_5fcache_5fmax_5fframes_9',['VIDEO_CACHE_MAX_FRAMES',['../classopenshot_1_1Settings.html#a95eb78b9202f69234dada483f38d6c03',1,'openshot::Settings']]],
  ['video_5fcache_5fmax_5fpreroll_5fframes_10',['VIDEO_CACHE_MAX_PREROLL_FRAMES',['../classopenshot_1_1Settings.html#af4a176e6d9cb64e5354ec4d19debd6ac',1,'openshot::Settings']]],
  ['video_5fcache_5fmin_5fpreroll_5fframes_11',['VIDEO_CACHE_MIN_PREROLL_FRAMES',['../classopenshot_1_1Settings.html#a875252749c32f03b5da0d86f8e76862c',1,'openshot::Settings']]],
  ['video_5fcache_5fpercent_5fahead_12',['VIDEO_CACHE_PERCENT_AHEAD',['../classopenshot_1_1Settings.html#acc6b24725d1c48837e45af1226c20c9c',1,'openshot::Settings']]],
  ['video_5fdecoded_13',['video_decoded',['../structopenshot_1_1PacketStatus.html#a827ec956bb15f1e61501e73ab36b64ef',1,'openshot::PacketStatus']]],
  ['video_5feof_14',['video_eof',['../structopenshot_1_1PacketStatus.html#aea56e6e74fab4544b761e781c2eff86c',1,'openshot::PacketStatus']]],
  ['video_5flength_15',['video_length',['../structopenshot_1_1ReaderInfo.html#a58fb59953df673c0240b6398b36f198f',1,'openshot::ReaderInfo::video_length'],['../structopenshot_1_1WriterInfo.html#a1ae6851f699eb16ce0f39fa9c72e9ba8',1,'openshot::WriterInfo::video_length']]],
  ['video_5fread_16',['video_read',['../structopenshot_1_1PacketStatus.html#a2d1c773f2d2ae14e45f11a7f1248d9da',1,'openshot::PacketStatus']]],
  ['video_5fstream_17',['VIDEO_STREAM',['../namespaceopenshot.html#ae2d6caab1dfb8202280cd5343a6505e3ae32ee67edd46165c463d8d2157004ca8',1,'openshot']]],
  ['video_5fstream_5findex_18',['video_stream_index',['../structopenshot_1_1ReaderInfo.html#ab3c62d7a199bf5de82f072c198a0dcdd',1,'openshot::ReaderInfo::video_stream_index'],['../structopenshot_1_1WriterInfo.html#abe6d885c6de152d1e223628eb647a2d4',1,'openshot::WriterInfo::video_stream_index']]],
  ['video_5ftimebase_19',['video_timebase',['../structopenshot_1_1ReaderInfo.html#ab1c961070c49398c485d5f016d7f25de',1,'openshot::ReaderInfo::video_timebase'],['../structopenshot_1_1WriterInfo.html#a91aa7f67fb7569726611be44aa5d011d',1,'openshot::WriterInfo::video_timebase']]],
  ['videocachethread_20',['VideoCacheThread',['../classopenshot_1_1VideoCacheThread.html',1,'openshot::VideoCacheThread'],['../classopenshot_1_1VideoCacheThread.html#a724e9c63303a008009d4f5dda68bfa8f',1,'openshot::VideoCacheThread::VideoCacheThread()']]],
  ['videocachethread_2ecpp_21',['VideoCacheThread.cpp',['../VideoCacheThread_8cpp.html',1,'']]],
  ['videocachethread_2eh_22',['VideoCacheThread.h',['../VideoCacheThread_8h.html',1,'']]],
  ['videoplaybackthread_23',['VideoPlaybackThread',['../classopenshot_1_1VideoPlaybackThread.html',1,'openshot']]],
  ['videoplaybackthread_2ecpp_24',['VideoPlaybackThread.cpp',['../VideoPlaybackThread_8cpp.html',1,'']]],
  ['videoplaybackthread_2eh_25',['VideoPlaybackThread.h',['../VideoPlaybackThread_8h.html',1,'']]],
  ['videorenderer_26',['VideoRenderer',['../classVideoRenderer.html',1,'VideoRenderer'],['../classVideoRenderer.html#a8af553b52aa088507190150093dd2676',1,'VideoRenderer::VideoRenderer()']]],
  ['videorenderer_2ecpp_27',['VideoRenderer.cpp',['../VideoRenderer_8cpp.html',1,'']]],
  ['videorenderer_2eh_28',['VideoRenderer.h',['../VideoRenderer_8h.html',1,'']]],
  ['videorenderwidget_29',['VideoRenderWidget',['../classVideoRenderWidget.html',1,'VideoRenderWidget'],['../classVideoRenderWidget.html#aff205f3e99ad0eeaf76a24134f90ca1e',1,'VideoRenderWidget::VideoRenderWidget()']]],
  ['videorenderwidget_2ecpp_30',['VideoRenderWidget.cpp',['../VideoRenderWidget_8cpp.html',1,'']]],
  ['videorenderwidget_2eh_31',['VideoRenderWidget.h',['../VideoRenderWidget_8h.html',1,'']]],
  ['viewport_5fscale_32',['viewport_scale',['../classopenshot_1_1Timeline.html#a1225a0f042308fbaf609de1d27a394c0',1,'openshot::Timeline']]],
  ['viewport_5fx_33',['viewport_x',['../classopenshot_1_1Timeline.html#ae9ad76791f3b3075aca19e668430e888',1,'openshot::Timeline']]],
  ['viewport_5fy_34',['viewport_y',['../classopenshot_1_1Timeline.html#af9ea1523546d9312afb9514b24bfda43',1,'openshot::Timeline']]],
  ['visible_35',['visible',['../classopenshot_1_1TrackedObjectBase.html#a632a1fa24937f794247af676c648200a',1,'openshot::TrackedObjectBase']]],
  ['volume_36',['Volume',['../classopenshot_1_1PlayerBase.html#a5822abc4b487f5ce93952373d385eb84',1,'openshot::PlayerBase::Volume()=0'],['../classopenshot_1_1PlayerBase.html#a78be80618d729d1690bd236018f702f1',1,'openshot::PlayerBase::Volume(float new_volume)=0'],['../classopenshot_1_1QtPlayer.html#ab7dce1b851993fa750cb4da820c6381f',1,'openshot::QtPlayer::Volume()'],['../classopenshot_1_1QtPlayer.html#ae8bd803779a6eb011c200b11ca684b1f',1,'openshot::QtPlayer::Volume(float new_volume)']]],
  ['volume_37',['volume',['../classopenshot_1_1Clip.html#a9253001dabbb8fffd17f8ef3eec78596',1,'openshot::Clip::volume'],['../classopenshot_1_1PlayerBase.html#a3e0a8ee8470773b73e7f455244dce53a',1,'openshot::PlayerBase::volume']]],
  ['volume_5fmix_5faverage_38',['VOLUME_MIX_AVERAGE',['../namespaceopenshot.html#aab56179b76f10ed8680d6df8b77a080ba0234f08bf2a1ab7e0cd1d4f9b918c6c9',1,'openshot']]],
  ['volume_5fmix_5fnone_39',['VOLUME_MIX_NONE',['../namespaceopenshot.html#aab56179b76f10ed8680d6df8b77a080ba494683e0605eb9c22155d754921b47c0',1,'openshot']]],
  ['volume_5fmix_5freduce_40',['VOLUME_MIX_REDUCE',['../namespaceopenshot.html#aab56179b76f10ed8680d6df8b77a080ba6ad226272ac83f5c935973a620e0cf29',1,'openshot']]],
  ['volumemixtype_41',['VolumeMixType',['../namespaceopenshot.html#aab56179b76f10ed8680d6df8b77a080b',1,'openshot']]]
];
